@@ -1201,7 +1201,7 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
     reset_js_gensym_index();
 
     // let coreLib = "http://js.calcit-lang.org/calcit.core.js".escape()
-    let core_lib = to_js_import_name("calcit.core", false); // TODO js_mode
+    let core_lib = to_js_import_name("calcit.core", true); // TODO js_mode
 
     let mut defs_code = String::from(""); // code generated by functions
     let mut vals_code = String::from(""); // code generated by thunks
@@ -1302,7 +1302,7 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
               let import_target = wrap_js_str(&target_ns[1..]);
               import_code.push_str(&format!("\nimport * as {} from {};", escape_ns(&def), import_target));
             } else {
-              let import_target = to_js_import_name(&target_ns, false); // TODO js_mode
+              let import_target = to_js_import_name(&target_ns, true); // TODO js_mode
               import_code.push_str(&format!("\nimport * as {} from {};", escape_ns(&target_ns), import_target));
             }
           }
@@ -1318,7 +1318,7 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
             let import_target = if is_cirru_string(&target_ns) {
               wrap_js_str(&target_ns[1..])
             } else {
-              to_js_import_name(&target_ns, false) // TODO js_mode
+              to_js_import_name(&target_ns, true) // TODO js_mode
             };
             import_code.push_str(&format!("\nimport {{ {} }} from {};", escape_var(&def), import_target));
           }
@@ -1343,7 +1343,7 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
     keywords_code.push_str(&snippets::tmpl_keywords_init(&kwd_arr, kwd_prefix));
     keywords_code.push('\n');
 
-    let js_file_path = code_emit_path.join(to_js_file_name(&ns, false)); // TODO mjs_mode
+    let js_file_path = code_emit_path.join(to_js_file_name(&ns, true)); // TODO mjs_mode
     let wrote_new = write_file_if_changed(
       &js_file_path,
       &format!(
